==> yadifa-2.4.0-9809.tar.gz: yadifa-2.4.0-9809/lib/dnscore/include/dnscore/dnscore-config-features.h <==
#pragma once
#define DNSCORE_DEFAULT_ASSUMED_CPU_COUNT 2
#define DNSCORE_HAS_ACL_SUPPORT 1
#define DNSCORE_HAS_BFD_DEBUG_SUPPORT 0
#define DNSCORE_HAS_BUILD_TIMESTAMP 1
#define DNSCORE_HAS_CC_ADDRESS_SANITIZER_CHECK 0
#define DNSCORE_HAS_CC_ANSI 1
#define DNSCORE_HAS_CC_ANSI_ALIAS 0
#define DNSCORE_HAS_CC_CATCH_UNDEFINED_BEHAVIOR 0
#define DNSCORE_HAS_CC_DWARF2 1
#define DNSCORE_HAS_CC_DWARF3 1
#define DNSCORE_HAS_CC_DWARF4 1
#define DNSCORE_HAS_CC_EXCEPTIONS 1
#define DNSCORE_HAS_CC_G 1
#define DNSCORE_HAS_CC_G3 1
#define DNSCORE_HAS_CC_M32 0
#define DNSCORE_HAS_CC_M64 1
#define DNSCORE_HAS_CC_MISSING_FIELD_INITIALIZERS 1
#define DNSCORE_HAS_CC_NO_IDENT 1
#define DNSCORE_HAS_CC_NO_OMIT_FRAME_POINTER 1
#define DNSCORE_HAS_CC_PEDANTIC 1
#define DNSCORE_HAS_CC_RDYNAMIC 1
#define DNSCORE_HAS_CC_SANITIZE_ADDRESS 0
#define DNSCORE_HAS_CC_STACK_PROTECTOR 1
#define DNSCORE_HAS_CC_STD_C11 1
#define DNSCORE_HAS_CC_STD_C99 1
#define DNSCORE_HAS_CC_STD_GNU11 1
#define DNSCORE_HAS_CC_STD_GNU99 1
#define DNSCORE_HAS_CC_TUNE_NATIVE 1
#define DNSCORE_HAS_CC_WALL 1
#define DNSCORE_HAS_CC_XC99 0
#define DNSCORE_HAS_CLOSE_EX_REF 0
#define DNSCORE_HAS_CPU_AMDINTEL 1
#define DNSCORE_HAS_CTRL 1
#define DNSCORE_HAS_DNSSEC_SUPPORT 1
#define DNSCORE_HAS_DNSSEC_TOOLS 1
#define DNSCORE_HAS_DYNUPDATE_SUPPORT 1
#define DNSCORE_HAS_ECDSA_SUPPORT 1
#define DNSCORE_HAS_EVENT_DYNAMIC_MODULE 0
#define DNSCORE_HAS_FILEPOOL_CACHE 0
#define DNSCORE_HAS_FULL_ASCII7 0
#define DNSCORE_HAS_LIBC_MALLOC_DEBUG_SUPPORT 0
#define DNSCORE_HAS_LOCK_DEBUG_SUPPORT 0
#define DNSCORE_HAS_LOGDIR 1
#define DNSCORE_HAS_LOG_PID 1
#define DNSCORE_HAS_LOG_THREAD_ID 0
#define DNSCORE_HAS_LOG_THREAD_TAG 1
#define DNSCORE_HAS_MALLOC_DEBUG_SUPPORT 0
#define DNSCORE_HAS_MASTER_SUPPORT 1
#define DNSCORE_HAS_MEMALIGN_ISSUES 0
#define DNSCORE_HAS_MREMAP 1
#define DNSCORE_HAS_MUTEX_DEBUG_SUPPORT 0
#define DNSCORE_HAS_NON_AA_AXFR_SUPPORT 0
#define DNSCORE_HAS_NSEC3_SUPPORT 1
#define DNSCORE_HAS_NSEC_SUPPORT 1
#define DNSCORE_HAS_NSID_SUPPORT 1
#define DNSCORE_HAS_OPENSSL 1
#define DNSCORE_HAS_PTHREAD_SETAFFINITY_NP 1
#define DNSCORE_HAS_PTHREAD_SETNAME_NP 1
#define DNSCORE_HAS_PTHREAD_SPINLOCK 1
#define DNSCORE_HAS_RRL_SUPPORT 1
#define DNSCORE_HAS_RRSIG_MANAGEMENT_SUPPORT 1
#define DNSCORE_HAS_SETGROUPS 1
#define DNSCORE_HAS_SOCKADDR_IN6_SIN6_LEN 0
#define DNSCORE_HAS_SOCKADDR_IN_SIN_LEN 0
#define DNSCORE_HAS_SOCKADDR_SA_LEN 0
#define DNSCORE_HAS_SYNC_BUILTINS 1
#define DNSCORE_HAS_SYSTEMD_RESOLVED_AVOIDANCE 0
#define DNSCORE_HAS_TESTS 1
#define DNSCORE_HAS_TIMEGM 1
#define DNSCORE_HAS_TOOLS 1
#define DNSCORE_HAS_TRACK_ZONES_DEBUG_SUPPORT 0
#define DNSCORE_HAS_TSIG_SUPPORT 1
#define DNSCORE_HAS_WITH_LOGDIR "${prefix}/var/log/yadifa" // ${prefix}/var/log/yadifa
#define DNSCORE_HAS_YADIFA 1
#define DNSCORE_HAS_ZALLOC_DEBUG_SUPPORT 0
#define DNSCORE_HAS_ZALLOC_STATISTICS_SUPPORT 0
#define DNSCORE_HAS_ZALLOC_SUPPORT 1
#define DNSCORE_HAVE_ARPA_INET_H 1
#define DNSCORE_HAVE_ASM_UNISTD_H 1
#define DNSCORE_HAVE_ASSERT_H 1
#define DNSCORE_HAVE_BYTESWAP_H 1
#define DNSCORE_HAVE_BZERO 1
#define DNSCORE_HAVE_CPUID_H 1
#define DNSCORE_HAVE_CTYPE_H 1
#define DNSCORE_HAVE_DIRENT_H 1
#define DNSCORE_HAVE_DLFCN_H 1
#define DNSCORE_HAVE_ENDIAN_H 1
#define DNSCORE_HAVE_ERRNO_H 1
#define DNSCORE_HAVE_EXECINFO_H 1
#define DNSCORE_HAVE_FCNTL_H 1
#define DNSCORE_HAVE_GETOPT_H 1
#define DNSCORE_HAVE_GRP_H 1
#define DNSCORE_HAVE_INT16_T 1
#define DNSCORE_HAVE_INT32_T 1
#define DNSCORE_HAVE_INT64_T 1
#define DNSCORE_HAVE_INT8_T 1
#define DNSCORE_HAVE_INTTYPES_H 1
#define DNSCORE_HAVE_LIBC 1
#define DNSCORE_HAVE_LIMITS_H 1
#define DNSCORE_HAVE_LINUX_LIMITS_H 1
#define DNSCORE_HAVE_LONG_LONG 1
#define DNSCORE_HAVE_MALLOC_H 1
#define DNSCORE_HAVE_MEMORY_H 1
#define DNSCORE_HAVE_MEMSET 1
#define DNSCORE_HAVE_NETDB_H 1
#define DNSCORE_HAVE_NETINET_IN_H 1
#define DNSCORE_HAVE_NETINET_TCP_H 1
#define DNSCORE_HAVE_NET_ETHERNET_H 1
#define DNSCORE_HAVE_POLL_H 1
#define DNSCORE_HAVE_PTHREAD_H 1
#define DNSCORE_HAVE_PWD_H 1
#define DNSCORE_HAVE_SCHED_H 1
#define DNSCORE_HAVE_SELECT 1
#define DNSCORE_HAVE_SIGNAL_H 1
#define DNSCORE_HAVE_SOCKET 1
#define DNSCORE_HAVE_STDARG_H 1
#define DNSCORE_HAVE_STDATOMIC_H 1
#define DNSCORE_HAVE_STDBOOL_H 1
#define DNSCORE_HAVE_STDDEF_H 1
#define DNSCORE_HAVE_STDINT_H 1
#define DNSCORE_HAVE_STDIO_H 1
#define DNSCORE_HAVE_STDLIB_H 1
#define DNSCORE_HAVE_STDNORETURN_H 1
#define DNSCORE_HAVE_STRINGS_H 1
#define DNSCORE_HAVE_STRING_H 1
#define DNSCORE_HAVE_SYSLOG_H 1
#define DNSCORE_HAVE_SYS_FILE_H 1
#define DNSCORE_HAVE_SYS_IPC_H 1
#define DNSCORE_HAVE_SYS_MMAN_H 1
#define DNSCORE_HAVE_SYS_MSG_H 1
#define DNSCORE_HAVE_SYS_PARAM_H 1
#define DNSCORE_HAVE_SYS_PRCTL_H 1
#define DNSCORE_HAVE_SYS_RESOURCE_H 1
#define DNSCORE_HAVE_SYS_SELECT_H 1
#define DNSCORE_HAVE_SYS_SOCKET_H 1
#define DNSCORE_HAVE_SYS_STAT_H 1
#define DNSCORE_HAVE_SYS_TIME_H 1
#define DNSCORE_HAVE_SYS_TYPES_H 1
#define DNSCORE_HAVE_SYS_UN_H 1
#define DNSCORE_HAVE_SYS_WAIT_H 1
#define DNSCORE_HAVE_TIME_H 1
#define DNSCORE_HAVE_UCONTEXT_H 1
#define DNSCORE_HAVE_UINT16_T 1
#define DNSCORE_HAVE_UINT32_T 1
#define DNSCORE_HAVE_UINT64_T 1
#define DNSCORE_HAVE_UINT8_T 1
#define DNSCORE_HAVE_UNISTD_H 1
#define DNSCORE_HAVE_U_CHAR 1
#define DNSCORE_IS_BSD_FAMILY 0
#define DNSCORE_IS_DARWIN_OS 0
#define DNSCORE_IS_LINUX_FAMILY 1
#define DNSCORE_IS_SOLARIS_FAMILY 0
#define DNSCORE_LSTAT_FOLLOWS_SLASHED_SYMLINK 1
#define DNSCORE_LT_OBJDIR ".libs/"
#define DNSCORE_PACKAGE "yadifa"
#define DNSCORE_PACKAGE_BUGREPORT "info@yadifa.eu"
#define DNSCORE_PACKAGE_NAME "yadifa"
#define DNSCORE_PACKAGE_STRING "yadifa 2.4.0-9809"
#define DNSCORE_PACKAGE_TARNAME "yadifa"
#define DNSCORE_PACKAGE_URL ""
#define DNSCORE_PACKAGE_VERSION "2.4.0-9809"
#define DNSCORE_RETSIGTYPE void
#define DNSCORE_SELECT_TYPE_ARG1 int
#define DNSCORE_SELECT_TYPE_ARG234 (fd_set *)
#define DNSCORE_SELECT_TYPE_ARG5 (struct timeval *)
#define DNSCORE_STDC_HEADERS 1
#define DNSCORE_VERSION "2.4.0-9809"
#undef DNSCORE_VERSION
// version 2.4.0.0-9809
#define DNSCORE_VERSION 0x020400002651LL// include/dnscore/dnscore-config-features.h

==> yadifa-2.4.1.tar.gz: yadifa-2.4.1/lib/dnscore/include/dnscore/dnscore-config-features.h <==
#pragma once
#define DNSCORE_DEFAULT_ASSUMED_CPU_COUNT 2
#define DNSCORE_HAS_ACL_SUPPORT 1
#define DNSCORE_HAS_BFD_DEBUG_SUPPORT 0
#define DNSCORE_HAS_BUILD_TIMESTAMP 1
#define DNSCORE_HAS_CC_ADDRESS_SANITIZER_CHECK 0
#define DNSCORE_HAS_CC_ANSI 1
#define DNSCORE_HAS_CC_ANSI_ALIAS 0
#define DNSCORE_HAS_CC_CATCH_UNDEFINED_BEHAVIOR 0
#define DNSCORE_HAS_CC_DWARF2 1
#define DNSCORE_HAS_CC_DWARF3 1
#define DNSCORE_HAS_CC_DWARF4 1
#define DNSCORE_HAS_CC_EXCEPTIONS 1
#define DNSCORE_HAS_CC_G 1
#define DNSCORE_HAS_CC_G3 1
#define DNSCORE_HAS_CC_M32 0
#define DNSCORE_HAS_CC_M64 1
#define DNSCORE_HAS_CC_MISSING_FIELD_INITIALIZERS 1
#define DNSCORE_HAS_CC_NO_IDENT 1
#define DNSCORE_HAS_CC_NO_OMIT_FRAME_POINTER 1
#define DNSCORE_HAS_CC_PEDANTIC 1
#define DNSCORE_HAS_CC_RDYNAMIC 1
#define DNSCORE_HAS_CC_SANITIZE_ADDRESS 0
#define DNSCORE_HAS_CC_STACK_PROTECTOR 1
#define DNSCORE_HAS_CC_STD_C11 1
#define DNSCORE_HAS_CC_STD_C99 1
#define DNSCORE_HAS_CC_STD_GNU11 1
#define DNSCORE_HAS_CC_STD_GNU99 1
#define DNSCORE_HAS_CC_TUNE_NATIVE 1
#define DNSCORE_HAS_CC_WALL 1
#define DNSCORE_HAS_CC_XC99 0
#define DNSCORE_HAS_CLOSE_EX_REF 0
#define DNSCORE_HAS_CPU_AMDINTEL 1
#define DNSCORE_HAS_CTRL 1
#define DNSCORE_HAS_DNSSEC_SUPPORT 1
#define DNSCORE_HAS_DNSSEC_TOOLS 1
#define DNSCORE_HAS_DYNUPDATE_SUPPORT 1
#define DNSCORE_HAS_ECDSA_SUPPORT 1
#define DNSCORE_HAS_EVENT_DYNAMIC_MODULE 0
#define DNSCORE_HAS_FILEPOOL_CACHE 0
#define DNSCORE_HAS_FULL_ASCII7 0
#define DNSCORE_HAS_KEYGEN 0
#define DNSCORE_HAS_LIBC_MALLOC_DEBUG_SUPPORT 0
#define DNSCORE_HAS_LOCK_DEBUG_SUPPORT 0
#define DNSCORE_HAS_LOGDIR 1
#define DNSCORE_HAS_LOG_PID 1
#define DNSCORE_HAS_LOG_THREAD_ID 0
#define DNSCORE_HAS_LOG_THREAD_TAG 1
#define DNSCORE_HAS_MALLOC_DEBUG_SUPPORT 0
#define DNSCORE_HAS_MASTER_SUPPORT 1
#define DNSCORE_HAS_MEMALIGN_ISSUES 0
#define DNSCORE_HAS_MREMAP 1
#define DNSCORE_HAS_MUTEX_DEBUG_SUPPORT 0
#define DNSCORE_HAS_NON_AA_AXFR_SUPPORT 0
#define DNSCORE_HAS_NSEC3_SUPPORT 1
#define DNSCORE_HAS_NSEC_SUPPORT 1
#define DNSCORE_HAS_NSID_SUPPORT 1
#define DNSCORE_HAS_OPENSSL 1
#define DNSCORE_HAS_PTHREAD_SETAFFINITY_NP 1
#define DNSCORE_HAS_PTHREAD_SETNAME_NP 1
#define DNSCORE_HAS_PTHREAD_SPINLOCK 1
#define DNSCORE_HAS_RRL_SUPPORT 1
#define DNSCORE_HAS_RRSIG_MANAGEMENT_SUPPORT 1
#define DNSCORE_HAS_SETGROUPS 1
#define DNSCORE_HAS_SOCKADDR_IN6_SIN6_LEN 0
#define DNSCORE_HAS_SOCKADDR_IN_SIN_LEN 0
#define DNSCORE_HAS_SOCKADDR_SA_LEN 0
#define DNSCORE_HAS_SYNC_BUILTINS 1
#define DNSCORE_HAS_SYSTEMD_RESOLVED_AVOIDANCE 0
#define DNSCORE_HAS_TESTS 1
#define DNSCORE_HAS_TIMEGM 1
#define DNSCORE_HAS_TOOLS 1
#define DNSCORE_HAS_TRACK_ZONES_DEBUG_SUPPORT 0
#define DNSCORE_HAS_TSIG_SUPPORT 1
#define DNSCORE_HAS_WITH_LOGDIR "${prefix}/var/log/yadifa" // ${prefix}/var/log/yadifa
#define DNSCORE_HAS_YADIFA 1
#define DNSCORE_HAS_ZALLOC_DEBUG_SUPPORT 0
#define DNSCORE_HAS_ZALLOC_STATISTICS_SUPPORT 0
#define DNSCORE_HAS_ZALLOC_SUPPORT 1
#define DNSCORE_HAS_ZONESIGN 0
#define DNSCORE_HAVE_ARPA_INET_H 1
#define DNSCORE_HAVE_ASM_UNISTD_H 1
#define DNSCORE_HAVE_ASSERT_H 1
#define DNSCORE_HAVE_BYTESWAP_H 1
#define DNSCORE_HAVE_BZERO 1
#define DNSCORE_HAVE_CPUID_H 1
#define DNSCORE_HAVE_CTYPE_H 1
#define DNSCORE_HAVE_DIRENT_H 1
#define DNSCORE_HAVE_DLFCN_H 1
#define DNSCORE_HAVE_ENDIAN_H 1
#define DNSCORE_HAVE_ERRNO_H 1
#define DNSCORE_HAVE_EXECINFO_H 1
#define DNSCORE_HAVE_FCNTL_H 1
#define DNSCORE_HAVE_GETOPT_H 1
#define DNSCORE_HAVE_GRP_H 1
#define DNSCORE_HAVE_INT16_T 1
#define DNSCORE_HAVE_INT32_T 1
#define DNSCORE_HAVE_INT64_T 1
#define DNSCORE_HAVE_INT8_T 1
#define DNSCORE_HAVE_INTTYPES_H 1
#define DNSCORE_HAVE_LIBC 1
#define DNSCORE_HAVE_LIMITS_H 1
#define DNSCORE_HAVE_LINUX_LIMITS_H 1
#define DNSCORE_HAVE_LONG_LONG 1
#define DNSCORE_HAVE_MALLOC_H 1
#define DNSCORE_HAVE_MEMORY_H 1
#define DNSCORE_HAVE_MEMSET 1
#define DNSCORE_HAVE_NETDB_H 1
#define DNSCORE_HAVE_NETINET_IN_H 1
#define DNSCORE_HAVE_NETINET_TCP_H 1
#define DNSCORE_HAVE_NET_ETHERNET_H 1
#define DNSCORE_HAVE_POLL_H 1
#define DNSCORE_HAVE_PTHREAD_H 1
#define DNSCORE_HAVE_PWD_H 1
#define DNSCORE_HAVE_RECVMMSG 1
#define DNSCORE_HAVE_SCHED_H 1
#define DNSCORE_HAVE_SELECT 1
#define DNSCORE_HAVE_SENDMMSG 1
#define DNSCORE_HAVE_SIGNAL_H 1
#define DNSCORE_HAVE_SOCKET 1
#define DNSCORE_HAVE_STDARG_H 1
#define DNSCORE_HAVE_STDATOMIC_H 1
#define DNSCORE_HAVE_STDBOOL_H 1
#define DNSCORE_HAVE_STDDEF_H 1
#define DNSCORE_HAVE_STDINT_H 1
#define DNSCORE_HAVE_STDIO_H 1
#define DNSCORE_HAVE_STDLIB_H 1
#define DNSCORE_HAVE_STDNORETURN_H 1
#define DNSCORE_HAVE_STRINGS_H 1
#define DNSCORE_HAVE_STRING_H 1
#define DNSCORE_HAVE_SYSLOG_H 1
#define DNSCORE_HAVE_SYS_FILE_H 1
#define DNSCORE_HAVE_SYS_IPC_H 1
#define DNSCORE_HAVE_SYS_MMAN_H 1
#define DNSCORE_HAVE_SYS_MSG_H 1
#define DNSCORE_HAVE_SYS_PARAM_H 1
#define DNSCORE_HAVE_SYS_PRCTL_H 1
#define DNSCORE_HAVE_SYS_RESOURCE_H 1
#define DNSCORE_HAVE_SYS_SELECT_H 1
#define DNSCORE_HAVE_SYS_SOCKET_H 1
#define DNSCORE_HAVE_SYS_STAT_H 1
#define DNSCORE_HAVE_SYS_TIME_H 1
#define DNSCORE_HAVE_SYS_TYPES_H 1
#define DNSCORE_HAVE_SYS_UN_H 1
#define DNSCORE_HAVE_SYS_WAIT_H 1
#define DNSCORE_HAVE_TIME_H 1
#define DNSCORE_HAVE_UCONTEXT_H 1
#define DNSCORE_HAVE_UINT16_T 1
#define DNSCORE_HAVE_UINT32_T 1
#define DNSCORE_HAVE_UINT64_T 1
#define DNSCORE_HAVE_UINT8_T 1
#define DNSCORE_HAVE_UNISTD_H 1
#define DNSCORE_HAVE_U_CHAR 1
#define DNSCORE_IS_BSD_FAMILY 0
#define DNSCORE_IS_DARWIN_OS 0
#define DNSCORE_IS_LINUX_FAMILY 1
#define DNSCORE_IS_SOLARIS_FAMILY 0
#define DNSCORE_LSTAT_FOLLOWS_SLASHED_SYMLINK 1
#define DNSCORE_LT_OBJDIR ".libs/"
#define DNSCORE_PACKAGE "yadifa"
#define DNSCORE_PACKAGE_BUGREPORT "info@yadifa.eu"
#define DNSCORE_PACKAGE_NAME "yadifa"
#define DNSCORE_PACKAGE_STRING "yadifa 2.4.1-9916"
#define DNSCORE_PACKAGE_TARNAME "yadifa"
#define DNSCORE_PACKAGE_URL ""
#define DNSCORE_PACKAGE_VERSION "2.4.1-9916"
#define DNSCORE_RETSIGTYPE void
#define DNSCORE_SELECT_TYPE_ARG1 int
#define DNSCORE_SELECT_TYPE_ARG234 (fd_set *)
#define DNSCORE_SELECT_TYPE_ARG5 (struct timeval *)
#define DNSCORE_STDC_HEADERS 1
#define DNSCORE_VERSION "2.4.1-9916"
#undef DNSCORE_VERSION
// version 2.4.1.0-9916
#define DNSCORE_VERSION 0x0204010026bcLL// include/dnscore/dnscore-config-features.h
